summaryrefslogtreecommitdiffstats
path: root/kdirstat/kdirstatsettings.h
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-07-04 21:28:42 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-07-04 21:28:42 +0000
commite8d62395de6c1b3844294c5b6c09428c315ac42a (patch)
treef94a43e157b5b4607f3a8d5b9b7be873d458fafa /kdirstat/kdirstatsettings.h
parent1ed26cd2c4d896ae560dc7dddb570fe14ef573f3 (diff)
downloadkdirstat-e8d62395de6c1b3844294c5b6c09428c315ac42a.tar.gz
kdirstat-e8d62395de6c1b3844294c5b6c09428c315ac42a.zip
TQt4 port kdirstat
This enables compilation under both Qt3 and Qt4 git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/applications/kdirstat@1239296 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'kdirstat/kdirstatsettings.h')
-rw-r--r--kdirstat/kdirstatsettings.h140
1 files changed, 74 insertions, 66 deletions
diff --git a/kdirstat/kdirstatsettings.h b/kdirstat/kdirstatsettings.h
index 0091f09..078860a 100644
--- a/kdirstat/kdirstatsettings.h
+++ b/kdirstat/kdirstatsettings.h
@@ -16,23 +16,23 @@
# include <config.h>
#endif
-#include <qlistbox.h>
+#include <tqlistbox.h>
#include <kdialogbase.h>
#include "kcleanup.h"
#include "kcleanupcollection.h"
#include "kdirstatapp.h"
-class QCheckBox;
-class QComboBox;
-class QHGroupBox;
-class QLabel;
-class QLineEdit;
-class QRadioButton;
-class QSlider;
-class QSpinBox;
-class QVGroupBox;
-class QWidget;
+class TQCheckBox;
+class TQComboBox;
+class TQHGroupBox;
+class TQLabel;
+class TQLineEdit;
+class TQRadioButton;
+class TQSlider;
+class TQSpinBox;
+class TQVGroupBox;
+class TQWidget;
class KColorButton;
@@ -56,14 +56,15 @@ namespace KDirStat
class KSettingsDialog: public KDialogBase
{
Q_OBJECT
+ TQ_OBJECT
public:
/**
* Constructor.
*
* Notice there is no parent widget passed but the application's main
* window so its functions can be accessed. The parent of this widget
* is always 0 since this is a dialog.
**/
@@ -76,11 +77,11 @@ namespace KDirStat
/**
- * Overwritten from @ref QDialog() to get any chance to set up the
+ * Overwritten from @ref TQDialog() to get any chance to set up the
* dialog contents when the dialog gets shown - every time, not just at
* program startup when the settings dialog is created (!).
*
- * QTabDialog used to have 'aboutToShow()' for a good reason, but the
+ * TQTabDialog used to have 'aboutToShow()' for a good reason, but the
* creators of @ref KDialogBase in their infinite wisdom chose not to
* include anything similar. How is that supposed to work, anyway?
* Everything I saw in any other KDE sources looked to me like ugly
@@ -89,7 +90,7 @@ namespace KDirStat
* certainly not be the way to go.
*
* This overwritten show() method sends that @ref aboutToShow() signal
* before calling the parent class show() method.
**/
virtual void show();
@@ -138,9 +139,10 @@ namespace KDirStat
* Note: This class contains pure virtuals - it cannot be
* instantiated. Rather, derive your own classes from this one.
**/
- class KSettingsPage: public QWidget
+ class KSettingsPage: public TQWidget
{
Q_OBJECT
+ TQ_OBJECT
public:
@@ -151,7 +153,7 @@ namespace KDirStat
* e.g., apply(), setup(), revertToDefaults().
**/
KSettingsPage( KSettingsDialog * dialog,
- QWidget * parent );
+ TQWidget * tqparent );
/**
* Destructor.
@@ -217,6 +219,7 @@ namespace KDirStat
class KTreeColorsPage: public KSettingsPage
{
Q_OBJECT
+ TQ_OBJECT
public:
@@ -224,7 +227,7 @@ namespace KDirStat
* Constructor
**/
KTreeColorsPage( KSettingsDialog * dialog,
- QWidget * parent,
+ TQWidget * tqparent,
KDirStatApp * mainWin );
/**
@@ -270,9 +273,9 @@ namespace KDirStat
KDirStatApp * _mainWin;
KDirTreeView * _treeView;
- QSlider * _slider;
+ TQSlider * _slider;
KColorButton * _colorButton [ KDirStatSettingsMaxColorButton ];
- QLabel * _colorLabel [ KDirStatSettingsMaxColorButton ];
+ TQLabel * _colorLabel [ KDirStatSettingsMaxColorButton ];
int _maxButtons;
@@ -295,6 +298,7 @@ namespace KDirStat
class KCleanupPage: public KSettingsPage
{
Q_OBJECT
+ TQ_OBJECT
public:
@@ -302,7 +306,7 @@ namespace KDirStat
* Constructor
**/
KCleanupPage( KSettingsDialog * dialog,
- QWidget * parent,
+ TQWidget * tqparent,
KDirStatApp * mainWin );
/**
@@ -392,24 +396,25 @@ namespace KDirStat
*
* This is meant as a substitute for a tabbed dialog inside the tabbed
* dialog which would be much too wide and possibly confusing. Plus, this
- * list box is supposed to take care of its own geometry - the normal
+ * list box is supposed to take care of its own tqgeometry - the normal
* dumbass list box obviously cannot do that. It just uses some random
- * geometry, relying on scroll bars for everything else. But in this
+ * tqgeometry, relying on scroll bars for everything else. But in this
* special case we want all items to be visible at all times without scroll
* bars.
*
* @short cleanup list box
**/
- class KCleanupListBox: public QListBox
+ class KCleanupListBox: public TQListBox
{
Q_OBJECT
+ TQ_OBJECT
public:
/**
* Constructor.
**/
- KCleanupListBox( QWidget * parent = 0 );
+ KCleanupListBox( TQWidget * tqparent = 0 );
/**
* Destructor.
@@ -421,7 +426,7 @@ namespace KDirStat
* without scrolling. In fact, we never want to see a scroll bar with
* this kind of list box.
**/
- virtual QSize sizeHint() const;
+ virtual TQSize tqsizeHint() const;
/**
* Insert an entry for a cleanup action into the list box. Uses the
@@ -454,7 +459,7 @@ namespace KDirStat
/**
* Select an item.
**/
- void selectCleanup( QListBoxItem * item );
+ void selectCleanup( TQListBoxItem * item );
protected:
@@ -468,7 +473,7 @@ namespace KDirStat
/**
* List box item for a KCleanupListBox.
**/
- class KCleanupListBoxItem: public QListBoxText
+ class KCleanupListBoxItem: public TQListBoxText
{
public:
@@ -504,16 +509,17 @@ namespace KDirStat
/**
* Properties page for one cleanup action.
**/
- class KCleanupPropertiesPage: public QWidget
+ class KCleanupPropertiesPage: public TQWidget
{
Q_OBJECT
+ TQ_OBJECT
public:
/**
* Constructor
**/
- KCleanupPropertiesPage( QWidget * parent,
+ KCleanupPropertiesPage( TQWidget * tqparent,
KDirStatApp * mainWin );
/**
@@ -540,18 +546,18 @@ namespace KDirStat
protected:
- QString _id;
- QCheckBox * _enabled;
- QWidget * _fields;
- QLineEdit * _title;
- QLineEdit * _command;
- QCheckBox * _recurse;
- QCheckBox * _askForConfirmation;
- QCheckBox * _worksForDir;
- QCheckBox * _worksForFile;
- QCheckBox * _worksForDotEntry;
- QComboBox * _worksForProtocols;
- QComboBox * _refreshPolicy;
+ TQString _id;
+ TQCheckBox * _enabled;
+ TQWidget * _fields;
+ TQLineEdit * _title;
+ TQLineEdit * _command;
+ TQCheckBox * _recurse;
+ TQCheckBox * _askForConfirmation;
+ TQCheckBox * _worksForDir;
+ TQCheckBox * _worksForFile;
+ TQCheckBox * _worksForDotEntry;
+ TQComboBox * _worksForProtocols;
+ TQComboBox * _refreshPolicy;
KDirStatApp * _mainWin;
@@ -565,6 +571,7 @@ namespace KDirStat
class KGeneralSettingsPage: public KSettingsPage
{
Q_OBJECT
+ TQ_OBJECT
public:
@@ -572,7 +579,7 @@ namespace KDirStat
* Constructor
**/
KGeneralSettingsPage( KSettingsDialog * dialog,
- QWidget * parent,
+ TQWidget * tqparent,
KDirStatApp * mainWin );
/**
@@ -618,11 +625,11 @@ namespace KDirStat
KDirStatApp * _mainWin;
KDirTreeView * _treeView;
- QCheckBox * _crossFileSystems;
- QCheckBox * _enableLocalDirReader;
+ TQCheckBox * _crossFileSystems;
+ TQCheckBox * _enableLocalDirReader;
- QCheckBox * _enableToolBarAnimation;
- QCheckBox * _enableTreeViewAnimation;
+ TQCheckBox * _enableToolBarAnimation;
+ TQCheckBox * _enableTreeViewAnimation;
}; // class KGeneralSettingsPage
@@ -634,6 +641,7 @@ namespace KDirStat
class KTreemapPage: public KSettingsPage
{
Q_OBJECT
+ TQ_OBJECT
public:
@@ -641,7 +649,7 @@ namespace KDirStat
* Constructor
**/
KTreemapPage( KSettingsDialog * dialog,
- QWidget * parent,
+ TQWidget * tqparent,
KDirStatApp * mainWin );
/**
@@ -691,9 +699,9 @@ namespace KDirStat
/**
* Convenience method to read a color from 'config'.
**/
- QColor readColorEntry( KConfig * config,
+ TQColor readColorEntry( KConfig * config,
const char * entryName,
- QColor defaultColor );
+ TQColor defaultColor );
// Data members
@@ -702,24 +710,24 @@ namespace KDirStat
// Widgets
- QCheckBox * _squarify;
- QCheckBox * _doCushionShading;
- QVGroupBox * _cushionParams;
- QSlider * _ambientLight;
- QSpinBox * _ambientLightSB;
- QSlider * _heightScalePercent;
- QSpinBox * _heightScalePercentSB;
- QCheckBox * _ensureContrast;
- QCheckBox * _forceCushionGrid;
+ TQCheckBox * _squarify;
+ TQCheckBox * _doCushionShading;
+ TQVGroupBox * _cushionParams;
+ TQSlider * _ambientLight;
+ TQSpinBox * _ambientLightSB;
+ TQSlider * _heightScalePercent;
+ TQSpinBox * _heightScalePercentSB;
+ TQCheckBox * _ensureContrast;
+ TQCheckBox * _forceCushionGrid;
KColorButton * _cushionGridColor;
- QLabel * _cushionGridColorL;
- QHGroupBox * _plainTileParams;
+ TQLabel * _cushionGridColorL;
+ TQHGroupBox * _plainTileParams;
KColorButton * _fileFillColor;
KColorButton * _dirFillColor;
KColorButton * _outlineColor;
KColorButton * _highlightColor;
- QSpinBox * _minTileSize;
- QCheckBox * _autoResize;
+ TQSpinBox * _minTileSize;
+ TQCheckBox * _autoResize;
}; // class KTreemapPage
@@ -729,12 +737,12 @@ namespace KDirStat
/**
* Add a horizontal stretch widget to take all excess space.
**/
-void addHStretch( QWidget * parent );
+void addHStretch( TQWidget * tqparent );
/**
* Add a vertical stretch widget to take all excess space.
**/
-void addVStretch( QWidget * parent );
+void addVStretch( TQWidget * tqparent );
@@ -56,14 +56,15 @@ namespace KDirStat
* Constructor.
*
- * Notice there is no parent widget passed but the application's main
- * window so its functions can be accessed. The parent of this widget
+ * Notice there is no tqparent widget passed but the application's main
+ * window so its functions can be accessed. The tqparent of this widget
* is always 0 since this is a dialog.
**/
@@ -89,7 +90,7 @@ namespace KDirStat
*
* This overwritten show() method sends that @ref aboutToShow() signal
- * before calling the parent class show() method.
+ * before calling the tqparent class show() method.
**/
virtual void show();